@@ -14,69 +14,12 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/***************************************************************************
- *  $Log: args.cpp,v $
- *  Revision 1.18  2004/05/05 23:49:20  s_a_white
- *  Remove the hardsid option from the args list if not sid devices are available.
- *
- *  Revision 1.17  2004/03/01 00:16:56  s_a_white
- *  ostream is part of std namespace.
- *
- *  Revision 1.16  2004/02/26 18:19:22  s_a_white
- *  Updates for VC7 (use real libstdc++ headers instead of draft ones).
- *
- *  Revision 1.15  2004/02/12 05:58:03  s_a_white
- *  Update argurements and help menu handling.
- *
- *  Revision 1.14  2004/01/31 17:07:44  s_a_white
- *  Support of specifing max sids writes forming sid2crc and experimental
- *  TSID2 library support.
- *
- *  Revision 1.13  2003/10/28 08:44:44  s_a_white
- *  Force being able to select MOS6581 from command line.
- *
- *  Revision 1.12  2003/06/27 21:09:00  s_a_white
- *  Better error checking on args and now displays invalid arguments.
- *
- *  Revision 1.11  2003/02/23 08:53:11  s_a_white
- *  Option none nolonger uses the audio hardware (removing realtime delays).
- *  New option nosid allows library profiling without the sid emulation.
- *
- *  Revision 1.10  2003/02/20 18:50:43  s_a_white
- *  sid2crc support.
- *
- *  Revision 1.9  2002/11/06 19:08:46  s_a_white
- *  Added --none to command line for selecting no sid (debug purposes).
- *
- *  Revision 1.8  2002/09/23 21:49:58  s_a_white
- *  Display error message on engine configuration failure.
- *
- *  Revision 1.7  2002/04/18 22:57:28  s_a_white
- *  Fixed use of track looping/single when creating audio files.
- *
- *  Revision 1.6  2002/03/11 18:02:56  s_a_white
- *  Display errors like sidplay1.
- *
- *  Revision 1.5  2002/01/29 08:11:43  s_a_white
- *  TSID filename fix
- *
- *  Revision 1.4  2002/01/29 00:49:49  jpaana
- *  Fixed a typo on in the TSID code
- *
- *  Revision 1.3  2002/01/28 19:40:50  s_a_white
- *  Added TSID support.
- *
- *  Revision 1.2  2001/12/01 20:16:23  s_a_white
- *  Player changed to ConsolePlayer.
- *
- *  Revision 1.1  2001/11/27 19:13:24  s_a_white
- *  Initial Release.
- *
- ***************************************************************************/
 
 #include <stdlib.h>
 #include <string.h>
 #include <iostream>
+#include <cstdlib>
+
 using std::cout;
 using std::cerr;
 using std::endl;
@@ -125,6 +68,17 @@ bool ConsolePlayer::parseTime (const char *str, uint_least32_t &time)
     return true;
 }
 
+bool ConsolePlayer::parseAddress (const char *str, uint_least16_t &address)
+{
+    if (*str == '\0')
+        return false;
+
+    long x = strtol(str, 0, 0);
+
+    address = x;
+    return true;
+}
+
 // Parse command line arguments
 int ConsolePlayer::args (int argc, const char *argv[])
 {
@@ -144,6 +98,7 @@ int ConsolePlayer::args (int argc, const char *argv[])
     m_driver.sid    = EMU_RESIDFP;
 
     v1mute = v2mute = v3mute = false;
+    v4mute = v5mute = v6mute = false;
 
     // parse command line arguments
     while ((i < argc) && (argv[i] != NULL))
@@ -167,13 +122,10 @@ int ConsolePlayer::args (int argc, const char *argv[])
                 if (!parseTime (&argv[i][2], m_timer.start))
                     err = true;
             }
-            else if (strcmp (&argv[i][1], "fd") == 0)
+            else if (strncmp (&argv[i][1], "ds", 2) == 0)
             {   // Override sidTune and enable the second sid
-                m_engCfg.forceDualSids = true;
-            }
-            else if (strcmp (&argv[i][1], "fs") == 0)
-            {   // Force samples through soundcard instead of SID
-                m_engCfg.sidSamples = false;
+                if (!parseAddress (&argv[i][3], m_engCfg.secondSidAddress))
+                    err = true;
             }
             else if (argv[i][1] == 'f')
             {
@@ -182,60 +134,11 @@ int ConsolePlayer::args (int argc, const char *argv[])
                 m_engCfg.frequency = (uint_least32_t) atoi (argv[i]+2);
             }
 
-            // Player Mode (Environment) Options ----------
-            else if (strcmp (&argv[i][1], "mb") == 0)
-            {   // Bankswitching
-                m_engCfg.environment = sid2_envBS;
-            }
-            else if (strcmp (&argv[i][1], "mr") == 0)
-            {   // Real C64
-                m_engCfg.environment = sid2_envR;
-            }
-            else if (strcmp (&argv[i][1], "mt") == 0)
-            {   // Transparent Rom
-                m_engCfg.environment = sid2_envTP;
-            }
-            else if (argv[i][1] == 'm')
-            {   // PlaySID
-                m_engCfg.environment = sid2_envPS;
-            }
-
             // No filter options
             else if (strncmp (&argv[i][1], "nf", 2) == 0)
             {
                 if (argv[i][3] == '\0')
                     m_filter.enabled = false;
-#if 0
-                else
-                {   // New filter
-                    // This line will open an existing file
-                    m_filter.enabled = true;
-                    m_filter.definition.read (&(argv[i][3]));
-                    if (!m_filter.definition)
-                    {
-                        displayError (m_filter.definition.error ());
-                        return -1;
-                    }
-                }
-#endif
-            }
-
-            // Newer sid (8580)
-            else if (strncmp (&argv[i][1], "ns", 2) == 0)
-            {
-                switch (argv[i][3])
-                {
-                case '\0':
-                case '1':
-                    m_engCfg.sidModel = SID2_MOS8580;
-                    break;
-                // No new sid so use old one (6581)
-                case '0':
-                    m_engCfg.sidModel = SID2_MOS6581;
-                    break;
-                default:
-                    err = true;
-                }
             }
 
             // Track options
@@ -275,6 +178,9 @@ int ConsolePlayer::args (int argc, const char *argv[])
                     case 1: v1mute = true; break;
                     case 2: v2mute = true; break;
                     case 3: v3mute = true; break;
+                    case 4: v4mute = true; break;
+                    case 5: v5mute = true; break;
+                    case 6: v6mute = true; break;
                     }
                 }
             }
@@ -302,7 +208,7 @@ int ConsolePlayer::args (int argc, const char *argv[])
 
             else if (argv[i][1] == 's')
             {   // Stereo Playback
-                m_engCfg.playback = sid2_stereo;
+                m_engCfg.playback = SidConfig::STEREO;
             }
 
             else if (argv[i][1] == 't')
@@ -315,45 +221,65 @@ int ConsolePlayer::args (int argc, const char *argv[])
             // Resampling Options ----------
             else if (strcmp (&argv[i][1], "rif") == 0)
             {
-                m_engCfg.samplingMethod = SID2_INTERPOLATE;
+                m_engCfg.samplingMethod = SidConfig::INTERPOLATE;
                 m_engCfg.fastSampling = true;
             }
             else if (strcmp (&argv[i][1], "rrf") == 0)
             {
-                m_engCfg.samplingMethod = SID2_RESAMPLE_INTERPOLATE;
+                m_engCfg.samplingMethod = SidConfig::RESAMPLE_INTERPOLATE;
                 m_engCfg.fastSampling = true;
             }
             else if (strcmp (&argv[i][1], "ri") == 0)
             {
-                m_engCfg.samplingMethod = SID2_INTERPOLATE;
+                m_engCfg.samplingMethod = SidConfig::INTERPOLATE;
             }
             else if (strcmp (&argv[i][1], "rr") == 0)
             {
-                m_engCfg.samplingMethod = SID2_RESAMPLE_INTERPOLATE;
+                m_engCfg.samplingMethod = SidConfig::RESAMPLE_INTERPOLATE;
+            }
+
+            // SID model options
+            else if (strcmp (&argv[i][1], "mof") == 0)
+            {
+                m_engCfg.defaultSidModel = SidConfig::MOS6581;
+                m_engCfg.forceSidModel = true;
+            }
+            else if (strcmp (&argv[i][1], "mnf") == 0)
+            {
+                m_engCfg.defaultSidModel = SidConfig::MOS8580;
+                m_engCfg.forceSidModel = true;
+            }
+            else if (strcmp (&argv[i][1], "mo") == 0)
+            {
+                m_engCfg.defaultSidModel = SidConfig::MOS6581;
+            }
+            else if (strcmp (&argv[i][1], "mn") == 0)
+            {
+                m_engCfg.defaultSidModel = SidConfig::MOS8580;
             }
 
             // Video/Verbose Options
             else if (strcmp (&argv[i][1], "vnf") == 0)
             {
-                m_engCfg.clockForced = true;
-                m_engCfg.clockSpeed  = SID2_CLOCK_NTSC;
+                m_engCfg.forceC64Model = true;
+                m_engCfg.defaultC64Model  = SidConfig::NTSC;
             }
             else if (strcmp (&argv[i][1], "vpf") == 0)
             {
-                m_engCfg.clockForced = true;
-                m_engCfg.clockSpeed  = SID2_CLOCK_PAL;
+                m_engCfg.forceC64Model = true;
+                m_engCfg.defaultC64Model  = SidConfig::PAL;
             }
             else if (strcmp (&argv[i][1], "vf") == 0)
             {
-                m_engCfg.clockForced = true;
+                m_engCfg.forceC64Model = true;
             }
             else if (strcmp (&argv[i][1], "vn") == 0)
             {
-                m_engCfg.clockSpeed  = SID2_CLOCK_NTSC;
+                m_engCfg.defaultC64Model  = SidConfig::NTSC;
             }
             else if (strcmp (&argv[i][1], "vp") == 0)
             {
-                m_engCfg.clockSpeed  = SID2_CLOCK_PAL;
+                m_engCfg.defaultC64Model  = SidConfig::PAL;
             }
             else if (argv[i][1] == 'v')
             {
@@ -362,12 +288,6 @@ int ConsolePlayer::args (int argc, const char *argv[])
                 else
                     m_verboseLevel = atoi(&argv[i][2]);
             }
-            else if (strncmp (&argv[i][1], "-crc", 4) == 0)
-            {
-                m_crc = ~0;
-                if (argv[i][5] == '=')
-                    m_crc = (uint_least32_t) atoi(&argv[i][6]);
-            }
             else if (strncmp (&argv[i][1], "-delay=", 7) == 0)
             {
                 m_engCfg.powerOnDelay = (uint_least16_t) atoi(&argv[i][8]);
@@ -460,9 +380,9 @@ int ConsolePlayer::args (int argc, const char *argv[])
     // Load the tune
     m_filename = argv[infile];
     m_tune.load (m_filename);
-    if (!m_tune)
+    if (!m_tune.getStatus())
     {
-        displayError ((m_tune.getInfo ()).statusString);
+        displayError (m_tune.statusString());
         return -1;
     }
 
@@ -488,13 +408,6 @@ int ConsolePlayer::args (int argc, const char *argv[])
     if (m_track.single)
         m_track.songs = 1;
 
-    // CRC handling (remove random behaviour)
-    if (m_crc)
-    {
-        m_engCfg.powerOnDelay = 0;
-        m_engCfg.sid2crcCount = m_crc;
-    }
-
     // If user provided no time then load songlength database
     // and set default lengths incase it's not found in there.
     {
@@ -511,7 +424,7 @@ int ConsolePlayer::args (int argc, const char *argv[])
                 m_timer.length = (m_iniCfg.sidplay2()).recordLength;
             if (database && (*database != '\0'))
             {   // Try loading the database specificed by the user
-                if (m_database.open (database) < 0)
+                if (!m_database.open (database))
                 {
                     displayError (m_database.error ());
                     return -1;
@@ -554,14 +467,12 @@ void ConsolePlayer::displayArgs (const char *arg)
         << " -b<num>      set start time in [m:]s format (default 0)" << endl
 
         << " -f<num>      set frequency in Hz (default: "
-        << SID2_DEFAULT_SAMPLING_FREQ << ")" << endl
-        << " -fd          force dual sid environment" << endl
-        << " -fs          force samples to a channel (default: uses sid)" << endl
+        << SidConfig::DEFAULT_SAMPLING_FREQ << ")" << endl
+        << " -ds<addr>    set second sid address (e.g. -dsd420)" << endl
 
-        << "-u<num>       mute voice <num> (e.g. -u1 -u2)" << endl
+        << " -u<num>      mute voice <num> (e.g. -u1 -u2)" << endl
 
         << " -nf          no SID filter emulation" << endl
-        << " -ns[0|1]     (no) MOS 8580 waveforms (default: from tune or cfg)" << endl
 
         << " -o<l|s>      looping and/or single track" << endl
         << " -o<num>      start track (default: preset)" << endl
@@ -579,6 +490,9 @@ void ConsolePlayer::displayArgs (const char *arg)
         << " -v[p|n][f]   set VIC PAL/NTSC clock speed (default: defined by song)" << endl
         << "              Use 'f' to force the clock by preventing speed fixing" << endl
 
+        << " -m<o|n>[f]   set SID new/old chip model (default: old)" << endl
+        << "              Use 'f' to force the model" << endl
+
         << " -r[i|r][f]   set resampling method (default: resample interpolate)" << endl
         << "              Use 'f' to enable fast resampling (only for reSID)" << endl
 
@@ -595,7 +509,7 @@ void ConsolePlayer::displayArgs (const char *arg)
 #ifdef HAVE_SIDPLAYFP_BUILDERS_HARDSID_H
     {
         HardSIDBuilder hs("");
-        if (hs.devices (false))
+        if (hs.availDevices ())
             out << " --hardsid    enable hardsid support" << endl;
     }
 #endif
@@ -612,14 +526,8 @@ void ConsolePlayer::displayDebugArgs ()
 
     out << "Debug Options:" << endl
         << " --cpu-debug   display cpu register and assembly dumps" << endl
-        << " --crc[=<num>] generate CRC for [<num>] sid writes (default: 0)" << endl
         << " --delay=<num> simulate c64 power on delay" << endl
 
-        << " -m            PlaySID compatibility mode (read the docs!)" << endl
-        << " -mt           Sidplays Transparent Rom mode" << endl
-        << " -mb           Sidplays Bankswitching mode" << endl
-        << " -mr           Real C64 mode (default)>" << endl
-
         << " --none        no audio output device" << endl
         << " --nosid       no sid emulation" << endl;
 }
