@@ -14,53 +14,6 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/***************************************************************************
- *  $Log: menu.cpp,v $
- *  Revision 1.14  2004/02/26 18:19:22  s_a_white
- *  Updates for VC7 (use real libstdc++ headers instead of draft ones).
- *
- *  Revision 1.13  2004/02/09 23:42:50  s_a_white
- *  Fixed damaged menu border shown using verbose option.
- *
- *  Revision 1.12  2004/01/31 17:07:45  s_a_white
- *  Support of specifing max sids writes forming sid2crc and experimental
- *  TSID2 library support.
- *
- *  Revision 1.11  2003/10/28 00:26:00  s_a_white
- *  Display power on cycles count for a loaded song.
- *
- *  Revision 1.10  2003/09/14 13:47:41  s_a_white
- *  Show whether the environment was forcefully changed from the default
- *  or user requested.
- *
- *  Revision 1.9  2003/07/16 06:53:12  s_a_white
- *  Only display tune description strings if they have been provided.
- *
- *  Revision 1.8  2003/02/20 18:50:44  s_a_white
- *  sid2crc support.
- *
- *  Revision 1.7  2002/11/22 08:35:16  s_a_white
- *  Renamed "Copyright" to "Released".
- *
- *  Revision 1.6  2002/03/04 19:28:28  s_a_white
- *  Displays more details about sidplay2s psid driver.
- *
- *  Revision 1.5  2002/01/29 21:55:29  s_a_white
- *  Display actual environment mode instead of requested one.
- *
- *  Revision 1.4  2002/01/28 19:40:50  s_a_white
- *  Added TSID support.
- *
- *  Revision 1.3  2002/01/15 19:12:24  s_a_white
- *  PSID2NG update.
- *
- *  Revision 1.2  2001/12/01 20:16:23  s_a_white
- *  Player changed to ConsolePlayer.
- *
- *  Revision 1.1  2001/11/27 19:10:44  s_a_white
- *  Initial Release.
- *
- ***************************************************************************/
 
 #include <ctype.h>
 #include <iostream>
@@ -75,12 +28,15 @@ using std::setw;
 using std::setfill;
 #include "player.h"
 
+#include <sidplayfp/SidInfo.h>
+#include <sidplayfp/SidTuneInfo.h>
+
 
 // Display console menu
 void ConsolePlayer::menu ()
 {
-    const sid2_info_t &info     = m_engine.info ();
-    const SidTuneInfo &tuneInfo = *info.tuneInfo;
+    const SidInfo &info         = m_engine.info ();
+    const SidTuneInfo *tuneInfo = m_tune.getInfo();
 
     if (m_quietLevel > 1)
         return;
@@ -105,71 +61,68 @@ void ConsolePlayer::menu ()
     consoleColour (white, false);
     {
         cerr << setw(19) << "Sidplayfp" << " V" << VERSION << ", ";
-        cerr << (char) toupper (*info.name);
-        cerr << info.name + 1 << " V" << info.version << endl;
+        cerr << (char) toupper (*info.name());
+        cerr << info.name() + 1 << " V" << info.version() << endl;
     }
 
     consoleTable (tableSeperator);
-    if (tuneInfo.numberOfInfoStrings > 0)
+
+    if (tuneInfo->numberOfInfoStrings() == 3) //FIXME
     {
-        if (!tuneInfo.musPlayer && (tuneInfo.numberOfInfoStrings == 3))
-        {
-            consoleTable  (tableMiddle);
-            consoleColour (cyan, true);
-            cerr << " Title        : ";
-            consoleColour (magenta, true);
-            cerr << tuneInfo.infoString[0] << endl;
-            consoleTable  (tableMiddle);
-            consoleColour (cyan, true);
-            cerr << " Author       : ";
-            consoleColour (magenta, true);
-            cerr << tuneInfo.infoString[1] << endl;
-            consoleTable  (tableMiddle);
-            consoleColour (cyan, true);
-            cerr << " Released     : ";
-            consoleColour (magenta, true);
-            cerr << tuneInfo.infoString[2] << endl;
-        }
-        else
-        {
-            for (int i = 0; i < tuneInfo.numberOfInfoStrings; i++)
-            {
-                consoleTable  (tableMiddle);
-                consoleColour (cyan, true);
-                cerr << " Description  : ";
-                consoleColour (magenta, true);
-                cerr << tuneInfo.infoString[i] << endl;
-            }
-        }
-        consoleTable (tableSeperator);
+        consoleTable  (tableMiddle);
+        consoleColour (cyan, true);
+        cerr << " Title        : ";
+        consoleColour (magenta, true);
+        cerr << tuneInfo->infoString(0) << endl;
+        consoleTable  (tableMiddle);
+        consoleColour (cyan, true);
+        cerr << " Author       : ";
+        consoleColour (magenta, true);
+        cerr << tuneInfo->infoString(1) << endl;
+        consoleTable  (tableMiddle);
+        consoleColour (cyan, true);
+        cerr << " Released     : ";
+        consoleColour (magenta, true);
+        cerr << tuneInfo->infoString(2) << endl;
     }
 
+    for (unsigned int i = 0; i < tuneInfo->numberOfCommentStrings(); i++)
+    {
+        consoleTable  (tableMiddle);
+        consoleColour (cyan, true);
+        cerr << " Comment      : ";
+        consoleColour (magenta, true);
+        cerr << tuneInfo->commentString(i) << endl;
+    }
+
+    consoleTable (tableSeperator);
+
     if (m_verboseLevel)
     {
         consoleTable  (tableMiddle);
         consoleColour (green, true);
         cerr << " File format  : ";
         consoleColour (white, true);
-        cerr << tuneInfo.formatString << endl;
+        cerr << tuneInfo->formatString() << endl;
         consoleTable  (tableMiddle);
         consoleColour (green, true);
         cerr << " Filename(s)  : ";
         consoleColour (white, true);
-        cerr << tuneInfo.dataFileName << endl;
+        cerr << tuneInfo->dataFileName() << endl;
         // Second file is only sometimes present
-        if (tuneInfo.infoFileName[0])
+        if (tuneInfo->infoFileName())
         {
             consoleTable  (tableMiddle);
             consoleColour (green, true);
             cerr << "              : ";
             consoleColour (white, true);
-            cerr << tuneInfo.infoFileName << endl;
+            cerr << tuneInfo->infoFileName() << endl;
         }
         consoleTable  (tableMiddle);
         consoleColour (green, true);
         cerr << " Condition    : ";
         consoleColour (white, true);
-        cerr << tuneInfo.statusString << endl;
+        cerr << m_tune.statusString() << endl;
 
 #if HAVE_TSID == 1
         if (!m_tsid)
@@ -198,9 +151,9 @@ void ConsolePlayer::menu ()
                 i += m_track.songs;
         }
         cerr << i << '/' << m_track.songs;
-        cerr << " (tune " << tuneInfo.currentSong << '/'
-             << tuneInfo.songs << '['
-             << tuneInfo.startSong << "])";
+        cerr << " (tune " << tuneInfo->currentSong() << '/'
+             << tuneInfo->songs() << '['
+             << tuneInfo->startSong() << "])";
     }
 
     if (m_track.loop)
@@ -213,7 +166,7 @@ void ConsolePlayer::menu ()
         consoleColour (green, true);
         cerr << " Song Speed   : ";
         consoleColour (white, true);
-        cerr << tuneInfo.speedString << endl;
+        cerr << info.speedString() << endl;
     }
 
     consoleTable  (tableMiddle);
@@ -244,28 +197,28 @@ void ConsolePlayer::menu ()
         consoleColour (white, false);
         // Display PSID Driver location
         cerr << "DRIVER = ";
-        if (info.driverAddr == 0)
+        if (info.driverAddr() == 0)
             cerr << "NOT PRESENT";
         else
         {
-            cerr << "$"  << setw(4) << setfill('0') << info.driverAddr;
-            cerr << "-$" << setw(4) << setfill('0') << info.driverAddr +
-                (info.driverLength - 1);
+            cerr << "$"  << setw(4) << setfill('0') << info.driverAddr();
+            cerr << "-$" << setw(4) << setfill('0') << info.driverAddr() +
+                (info.driverLength() - 1);
         }
-        if (tuneInfo.playAddr == 0xffff)
-            cerr << ", SYS = $" << setw(4) << setfill('0') << tuneInfo.initAddr;
+        if (tuneInfo->playAddr() == 0xffff)
+            cerr << ", SYS = $" << setw(4) << setfill('0') << tuneInfo->initAddr();
         else
-            cerr << ", INIT = $" << setw(4) << setfill('0') << tuneInfo.initAddr;
+            cerr << ", INIT = $" << setw(4) << setfill('0') << tuneInfo->initAddr();
         cerr << endl;
         consoleTable  (tableMiddle);
         consoleColour (yellow, true);
         cerr << "              : ";
         consoleColour (white, false);
-        cerr << "LOAD   = $" << setw(4) << setfill('0') << tuneInfo.loadAddr;
-        cerr << "-$"         << setw(4) << setfill('0') << tuneInfo.loadAddr +
-            (tuneInfo.c64dataLen - 1);
-        if (tuneInfo.playAddr != 0xffff)
-            cerr << ", PLAY = $" << setw(4) << setfill('0') << tuneInfo.playAddr;
+        cerr << "LOAD   = $" << setw(4) << setfill('0') << tuneInfo->loadAddr();
+        cerr << "-$"         << setw(4) << setfill('0') << tuneInfo->loadAddr() +
+            (tuneInfo->c64dataLen() - 1);
+        if (tuneInfo->playAddr() != 0xffff)
+            cerr << ", PLAY = $" << setw(4) << setfill('0') << tuneInfo->playAddr();
         cerr << dec << endl;
         cerr.unsetf(std::ios::uppercase);
 
@@ -275,37 +228,20 @@ void ConsolePlayer::menu ()
         consoleColour (white, false);
         cerr << "Filter = "
              << ((m_filter.enabled == true) ? "Yes" : "No");
-        cerr << ", Model = "
-             << (info.tuneInfo->sidModel1 == SID2_MOS8580 ? "8580" : "6581")
-             << endl;
-        consoleTable  (tableMiddle);
-        consoleColour (yellow, true);
-        cerr << " Environment  : ";
-        consoleColour (white, false);
-        switch (info.environment)
-        {
-        case sid2_envPS:
-            cerr << "PlaySID-specific rips";
-        break;
-        case sid2_envTP:
-            cerr << "Transparent ROM";
-        break;
-        case sid2_envBS:
-            cerr << "Bank Switching";
-        break;
-        case sid2_envR:  // When it happens
-            cerr << "Real C64";
-        break;
-        case sid2_envTR:
-            cerr << "Sidusage Tracker Mode";
-        break;
-        default:
-            cerr << "Unknown";
-        }
-
-        if (m_engCfg.environment != info.environment)
-            cerr << " (forced)";
+        cerr << ", Model = ";
+        cerr << getModel(tuneInfo->sidModel1());
         cerr << endl;
+        
+        if (tuneInfo->isStereo())
+        {
+            consoleTable  (tableMiddle);
+            consoleColour (yellow, true);
+            cerr << "              : ";
+            consoleColour (white, false);
+            cerr << "2nd SID = $" << hex << tuneInfo->sidChipBase2() << dec;
+            cerr << ", Model = " << getModel(tuneInfo->sidModel2());
+            cerr << endl;
+        }
 
         if (m_verboseLevel > 1)
         {
@@ -313,29 +249,30 @@ void ConsolePlayer::menu ()
             consoleColour (yellow, true);
             cerr << " Delay        : ";
             consoleColour (white, false);
-            cerr << info.powerOnDelay << " (cycles at poweron)" << endl;
+            cerr << info.powerOnDelay() << " (cycles at poweron)" << endl;
         }
+
+        consoleTable  (tableSeperator);
+        consoleTable  (tableMiddle);
+        consoleColour (magenta, true);
+        cerr << " Kernal ROM   : ";
+        consoleColour (white, false);
+        cerr << info.kernalDesc() << endl;
+
+        consoleTable  (tableMiddle);
+        consoleColour (magenta, true);
+        cerr << " BASIC ROM    : ";
+        consoleColour (white, false);
+        cerr << info.basicDesc() << endl;
+
+        consoleTable  (tableMiddle);
+        consoleColour (magenta, true);
+        cerr << " Chargen ROM  : ";
+        consoleColour (white, false);
+        cerr << info.chargenDesc() << endl;
     }
     consoleTable (tableEnd);
 
-/*
-    cerr << "Credits:\n";
-    const char **p;
-    const char  *credit;
-    p = m_engine.credits ();
-    while (*p)
-    {
-        credit = *p;
-        while (*credit)
-        {
-            cerr << credit << endl;
-            credit += strlen (credit) + 1;
-        }
-        cerr << endl;
-        p++;
-    }
-*/
-
     if (m_driver.file)
         cerr << "Creating audio file, please wait...";
     else
@@ -377,7 +314,7 @@ void ConsolePlayer::consoleColour (player_colour_t colour, bool bold)
 // Display menu outline
 void ConsolePlayer::consoleTable (player_table_t table)
 {
-    const uint tableWidth = 54;
+    const unsigned int tableWidth = 54;
 
     consoleColour (white, true);
     switch (table)
@@ -411,9 +348,25 @@ void ConsolePlayer::consoleTable (player_table_t table)
     cerr << "\n";
 }
 
+
 // Restore Ansi Console to defaults
 void ConsolePlayer::consoleRestore ()
 {
     if ((m_iniCfg.console ()).ansi)
         cerr << '\x1b' << "[0m";
 }
+
+const char* ConsolePlayer::getModel (SidTuneInfo::model_t model)
+{
+    switch (model)
+    {
+    case SidTuneInfo::SIDMODEL_UNKNOWN:
+        return "UNKNOWN";
+    case SidTuneInfo::SIDMODEL_6581:
+        return "6581";
+    case SidTuneInfo::SIDMODEL_8580:
+        return "8580";
+    case SidTuneInfo::SIDMODEL_ANY:
+        return "ANY";
+    }
+}
