@@ -14,124 +14,35 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/***************************************************************************
- *  $Log: player.cpp,v $
- *  Revision 1.31  2004/02/26 18:19:22  s_a_white
- *  Updates for VC7 (use real libstdc++ headers instead of draft ones).
- *
- *  Revision 1.30  2004/02/12 05:58:03  s_a_white
- *  Update argurements and help menu handling.
- *
- *  Revision 1.29  2004/01/31 17:07:45  s_a_white
- *  Support of specifing max sids writes forming sid2crc and experimental
- *  TSID2 library support.
- *
- *  Revision 1.28  2003/12/15 23:34:49  s_a_white
- *  Timebase for timers now obtainable from engine.
- *
- *  Revision 1.27  2003/10/18 12:45:12  s_a_white
- *  no message
- *
- *  Revision 1.26  2003/07/16 06:54:06  s_a_white
- *  Added sid2crc support.
- *
- *  Revision 1.25  2003/06/27 21:07:40  s_a_white
- *  Fixed problem whereby the audio buffer size was ever only calculated once.
- *
- *  Revision 1.24  2003/02/23 08:59:20  s_a_white
- *  Displayed keyboard checks at high quiet levels.   At these quiet levels we
- *  are most likely being run from within another program.
- *
- *  Revision 1.23  2003/02/22 09:41:59  s_a_white
- *  Made crcs be printed for every subtune automatically.
- *
- *  Revision 1.22  2003/02/20 18:50:44  s_a_white
- *  sid2crc support.
- *
- *  Revision 1.21  2003/01/20 16:26:18  s_a_white
- *  Updated for new event scheduler interface.
- *
- *  Revision 1.20  2003/01/14 20:37:10  s_a_white
- *  Updated previous song select timeout to 4 seconds.
- *
- *  Revision 1.19  2003/01/08 08:45:14  s_a_white
- *  Don't configure an emulation if it failed to be created.
- *
- *  Revision 1.18  2002/08/19 17:04:28  s_a_white
- *  Added timeout to decide if previous key should select previous song or
- *  restart current song.
- *
- *  Revision 1.17  2002/06/16 19:44:21  s_a_white
- *  Changing resid filter works again.
- *
- *  Revision 1.16  2002/04/18 22:57:28  s_a_white
- *  Fixed use of track looping/single when creating audio files.
- *
- *  Revision 1.15  2002/03/11 18:02:56  s_a_white
- *  Display errors like sidplay1.
- *
- *  Revision 1.14  2002/03/04 19:30:15  s_a_white
- *  Fix C++ use of nothrow.
- *
- *  Revision 1.13  2002/01/30 00:34:15  s_a_white
- *  Printing builder error message instead of not enough memory.
- *
- *  Revision 1.12  2002/01/29 08:11:43  s_a_white
- *  TSID filename fix
- *
- *  Revision 1.11  2002/01/28 19:40:50  s_a_white
- *  Added TSID support.
- *
- *  Revision 1.10  2002/01/16 19:54:56  s_a_white
- *  Fixed -b command arg with UNKNOWN songlengh.
- *
- *  Revision 1.9  2002/01/16 19:28:55  s_a_white
- *  Now now wraps at 100th minute.
- *
- *  Revision 1.8  2002/01/10 19:39:46  s_a_white
- *  Fixed default to switch to please solaris compiler.
- *
- *  Revision 1.7  2001/12/11 19:38:13  s_a_white
- *  More GCC3 Fixes.
- *
- *  Revision 1.6  2001/12/07 18:22:33  s_a_white
- *  Player quit fixes.
- *
- *  Revision 1.5  2001/12/05 22:22:48  s_a_white
- *  Added playerFast flag.
- *
- *  Revision 1.4  2001/12/03 20:00:24  s_a_white
- *  sidSamples no longer forced for hardsid.
- *
- *  Revision 1.3  2001/12/03 19:17:34  s_a_white
- *  Corrected spelling of BUILDER.
- *
- *  Revision 1.2  2001/12/01 20:16:23  s_a_white
- *  Player changed to ConsolePlayer.
- *
- *  Revision 1.1  2001/11/27 19:10:44  s_a_white
- *  Initial Release.
- *
- ***************************************************************************/
 
 #include <iostream>
 using std::cout;
 using std::cerr;
 using std::endl;
 #include <iomanip>
+#include <fstream>
+
 #include "config.h"
 
 #ifdef HAVE_EXCEPTIONS
 #   include <new>
 #endif
 
+#ifdef _WIN32
+#   include <shlobj.h>
+#endif
+
 #include "player.h"
 #include "keyboard.h"
 
 #ifdef MSVC_HEADER_LOCATIONS
 # include <sidbuilder.h>
+# include <SidInfo.h>
+# include <SidTuneInfo.h>
 #else
 # include <sidplayfp/sidbuilder.h>
+# include <sidplayfp/SidInfo.h>
+# include <sidplayfp/SidTuneInfo.h>
 #endif
 
 // Previous song select timeout (3 secs)
@@ -174,7 +85,6 @@ ConsolePlayer::ConsolePlayer (const char * const name)
  m_context(NULL),
  m_quietLevel(0),
  m_verboseLevel(0),
- m_crc(0),
  m_cpudebug(false)
 {   // Other defaults
     m_filename       = "";
@@ -199,15 +109,13 @@ ConsolePlayer::ConsolePlayer (const char * const name)
         IniConfig::emulation_section emulation = m_iniCfg.emulation();
 
         // INI Configuration Settings
-        m_engCfg.clockForced  = emulation.clockForced;
-        m_engCfg.clockSpeed   = emulation.clockSpeed;
-        m_engCfg.clockDefault = SID2_CLOCK_PAL;
+        m_engCfg.forceC64Model   = emulation.modelForced;
+        m_engCfg.defaultC64Model = emulation.modelDefault;
+        m_engCfg.defaultSidModel = emulation.sidModel;
+        m_engCfg.forceSidModel   = emulation.forceModel;
         m_engCfg.frequency    = audio.frequency;
         m_engCfg.playback     = audio.playback;
         m_precision           = audio.precision;
-        m_engCfg.sidModel     = emulation.sidModel;
-        m_engCfg.sidDefault   = SID2_MOS6581;
-        m_engCfg.sidSamples   = emulation.sidSamples;
         m_filter.enabled      = emulation.filter;
         m_filter.bias         = emulation.bias;
         m_filter.filterCurve6581 = emulation.filterCurve6581;
@@ -216,8 +124,72 @@ ConsolePlayer::ConsolePlayer (const char * const name)
 
     createOutput (OUT_NULL, NULL);
     createSidEmu (EMU_NONE);
+
+    uint8_t *kernalRom = loadRom((m_iniCfg.sidplay2()).kernalRom, 8192, "kernal");
+    uint8_t *basicRom = loadRom((m_iniCfg.sidplay2()).basicRom, 8192, "basic");
+    uint8_t *chargenRom = loadRom((m_iniCfg.sidplay2()).chargenRom, 4096, "chargen");
+    m_engine.setRoms(kernalRom, basicRom, chargenRom);
+    delete [] kernalRom;
+    delete [] basicRom;
+    delete [] chargenRom;
 }
 
+uint8_t* ConsolePlayer::loadRom(const char* romPath, const int size, const char defaultRom[])
+{
+    std::string dataPath;
+
+    // FIXME this code is dupicated in IniConfig.cpp
+#ifdef _WIN32
+    char szPath[MAX_PATH];
+
+    if (SHGetFolderPathA(NULL, CSIDL_APPDATA, NULL, 0, szPath)!=S_OK)
+    {
+        char *path = getenv("USERPROFILE");
+        if (!path)
+            return 0;
+        dataPath.append(path).append("\\Application Data");
+    }
+    else
+        dataPath.append(szPath);
+#else
+    char *path = getenv("XDG_DATA_HOME");
+    if (!path)
+    {
+        path = getenv("HOME");
+        if (!path)
+            return 0;
+        dataPath.append(path).append("/.local/share");
+    }
+    else
+        dataPath.append(path);
+#endif
+    dataPath.append("/sidplayfp/").append(defaultRom);
+
+    std::ifstream is((romPath)?romPath:dataPath.c_str(), std::ios::binary);
+
+    if (is.fail())
+        goto error;
+    {
+#ifdef HAVE_EXCEPTIONS
+    uint8_t *buffer = new(std::nothrow) uint8_t[size];
+#else
+    uint8_t *buffer = new uint8_t[size];
+#endif
+    if (buffer == 0)
+        goto error;
+
+    is.read((char*)buffer, size);
+    if (is.fail())
+        goto error;
+
+    is.close();
+    return buffer;
+    }
+
+error:
+    is.close();
+    return 0;
+}
 
 // Create the output object to process sound buffer
 bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
@@ -275,7 +247,7 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
     if (title == NULL)
     {
         size_t length, i;
-        title  = tuneInfo->dataFileName;
+        title  = tuneInfo->dataFileName();
         length = strlen (title);
         i      = length;
         while (i > 0)
@@ -301,8 +273,8 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
         name[i] = '\0';
 
         // Change name based on subtune
-        if (tuneInfo->songs > 1)
-            sprintf (&name[i], "[%u]", tuneInfo->currentSong);
+        if (tuneInfo->songs() > 1)
+            sprintf (&name[i], "[%u]", tuneInfo->currentSong());
         strcat (&name[i], m_driver.device->extension ());
         title = name;
     }
@@ -312,7 +284,7 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
     m_driver.cfg.precision = m_precision;
     m_driver.cfg.channels  = 1; // Mono
     m_driver.cfg.bufSize   = 0; // Recalculate
-    if (m_engCfg.playback == sid2_stereo)
+    if (m_engCfg.playback == SidConfig::STEREO)
         m_driver.cfg.channels = 2;
 
     {   // Open the hardware
@@ -339,12 +311,12 @@ bool ConsolePlayer::createOutput (OUTPUTS driver, const SidTuneInfo *tuneInfo)
     switch (m_driver.cfg.channels)
     {
     case 1:
-        if (m_engCfg.playback == sid2_stereo)
-            m_engCfg.playback  = sid2_mono;
+        if (m_engCfg.playback == SidConfig::STEREO)
+            m_engCfg.playback  = SidConfig::MONO;
         break;
     case 2:
-        if (m_engCfg.playback != sid2_stereo)
-            m_engCfg.playback  = sid2_stereo;
+        if (m_engCfg.playback != SidConfig::STEREO)
+            m_engCfg.playback  = SidConfig::STEREO;
         break;
     default:
         cerr << m_name << ": " << "ERROR: " << m_driver.cfg.channels
@@ -381,44 +353,10 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu)
         if (rs)
         {
             m_engCfg.sidEmulation = rs;
-            if (!*rs) goto createSidEmu_error;
-            rs->create ((m_engine.info ()).maxsids);
-            if (!*rs) goto createSidEmu_error;
-#if 0
-            if (m_filter.definition)
-            {
-                rs->filter(m_filter.definition.providefp());
-            }
-            else
-            {
-                /* figure out the model from settings and tuneinfo */
-                sid2_model_t model = m_engCfg.sidModel;
-                if (model == SID2_MODEL_CORRECT)
-                {
-                    switch (m_tune.getInfo().sidModel1)
-                    {
-                        case SIDTUNE_SIDMODEL_6581:
-                            model = SID2_MOS6581;
-                            break;
-                        case SIDTUNE_SIDMODEL_8580:
-                            model = SID2_MOS8580;
-                            break;
-                        default:
-                            /* Fuck, libsidplay should tell me which chip it chose
-                            * as I see the code setting it up into tuneinfo, but
-                            * it doesn't seem to work! I'll debug it; for now... */
-                            model = SID2_MOS6581;
-                            break;
-                    }
-                }
+            if (!rs->getStatus()) goto createSidEmu_error;
+            rs->create ((m_engine.info ()).maxsids());
+            if (!rs->getStatus()) goto createSidEmu_error;
 
-                /* NB: NULL means default */
-                const sid_filterfp_t *filter = m_iniCfg.filter(model);
-                rs->filter(filter);
-                if (! *m_engCfg.sidEmulation)
-                    goto createSidEmu_error;
-            }
-#endif
             if (m_filter.filterCurve6581)
                 rs->filter6581Curve(m_filter.filterCurve6581);
             if (m_filter.filterCurve8580)
@@ -439,9 +377,9 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu)
         if (rs)
         {
             m_engCfg.sidEmulation = rs;
-            if (!*rs) goto createSidEmu_error;
-            rs->create ((m_engine.info ()).maxsids);
-            if (!*rs) goto createSidEmu_error;
+            if (!rs->getStatus()) goto createSidEmu_error;
+            rs->create ((m_engine.info ()).maxsids());
+            if (!rs->getStatus()) goto createSidEmu_error;
 
             rs->bias(m_filter.bias);
         }
@@ -460,9 +398,9 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu)
         if (hs)
         {
             m_engCfg.sidEmulation = hs;
-            if (!*hs) goto createSidEmu_error;
-            hs->create ((m_engine.info ()).maxsids);
-            if (!*hs) goto createSidEmu_error;
+            if (!hs->getStatus()) goto createSidEmu_error;
+            hs->create ((m_engine.info ()).maxsids());
+            if (!hs->getStatus()) goto createSidEmu_error;
         }
         break;
     }
@@ -501,8 +439,6 @@ createSidEmu_error:
 
 bool ConsolePlayer::open (void)
 {
-    const SidTuneInfo *tuneInfo;
-
     if ((m_state & ~playerFast) == playerRestart)
     {
         if (m_quietLevel < 2)
@@ -521,16 +457,16 @@ bool ConsolePlayer::open (void)
     }
 
     // Get tune details
-    tuneInfo = (m_engine.info ()).tuneInfo;
+    const SidTuneInfo *tuneInfo = m_tune.getInfo ();
     if (!m_track.single)
-        m_track.songs = tuneInfo->songs;
+        m_track.songs = tuneInfo->songs();
     if (!createOutput (m_driver.output, tuneInfo))
         return false;
     if (!createSidEmu (m_driver.sid))
         return false;
 
     // Configure engine with settings
-    if (m_engine.config (m_engCfg) < 0)
+    if (!m_engine.config (m_engCfg))
     {   // Config failed
         displayError (m_engine.error ());
         return false;
@@ -542,9 +478,12 @@ bool ConsolePlayer::open (void)
     m_speed.current   = m_speed.max;
     m_engine.fastForward (100 * m_speed.current);
 
-    m_engine.mute(0, v1mute);
-    m_engine.mute(1, v2mute);
-    m_engine.mute(2, v3mute);
+    m_engine.mute(0, 0, v1mute);
+    m_engine.mute(0, 1, v2mute);
+    m_engine.mute(0, 2, v3mute);
+    m_engine.mute(1, 0, v4mute);
+    m_engine.mute(1, 1, v5mute);
+    m_engine.mute(1, 2, v6mute);
 
     // As yet we don't have a required songlength
     // so try the songlength database
@@ -556,7 +495,7 @@ bool ConsolePlayer::open (void)
     }
 
     // Set up the play timer
-    m_context = (m_engine.info()).eventContext;
+    m_context = m_engine.getEventContext();
     m_timer.stop  = 0;
     m_timer.stop += m_timer.length;
 
@@ -640,7 +579,7 @@ bool ConsolePlayer::play ()
         ret = m_engine.play (buffer, length);
         if (ret < length)
         {
-            if (m_engine.state () != sid2_stopped)
+            if (m_engine.isPlaying ())
             {
                 m_state = playerError;
                 return false;
@@ -664,14 +603,6 @@ bool ConsolePlayer::play ()
     default:
         if (m_quietLevel < 2)
             cerr << endl;
-        if (m_crc)
-        {
-            const SidTuneInfo *tuneInfo = (m_engine.info ()).tuneInfo;
-            cout << std::setw(8) << std::setfill('0') << std::hex
-                 << (m_engine.info ()).sid2crc << " : " << std::dec
-                 << m_filename << " - song " << tuneInfo->currentSong
-                 << "/" << tuneInfo->songs << endl;
-        }
         m_engine.stop ();
 #if HAVE_TSID == 1
         if (m_tsid)
@@ -683,7 +614,7 @@ bool ConsolePlayer::play ()
         if (m_tsid)
         {
             int_least32_t length;
-            char md5[SIDTUNE_MD5_LENGTH + 1];
+            char md5[SidTune::MD5_LENGTH + 1];
             m_tune.createMD5 (md5);
             length = m_database.length (md5, m_track.selected);
             // ignore errors
@@ -721,10 +652,6 @@ void ConsolePlayer::event (void)
     {
         m_timer.current = seconds;
 
-        // Handle exiting on crc completion
-        if (m_crc && (m_crc == (m_engine.info ()).sid2crcCount))
-            m_timer.stop = seconds;
-
         if (seconds == m_timer.start)
         {   // Switch audio drivers.
             m_driver.selected = m_driver.device;
@@ -844,17 +771,32 @@ void ConsolePlayer::decodeKeys ()
 
         case A_TOGGLE_VOICE1:
             v1mute = !v1mute;
-            m_engine.mute(0, v1mute);
+            m_engine.mute(0, 0, v1mute);
         break;
 
         case A_TOGGLE_VOICE2:
             v2mute = !v2mute;
-            m_engine.mute(1, v2mute);
+            m_engine.mute(0, 1, v2mute);
         break;
 
         case A_TOGGLE_VOICE3:
             v3mute = !v3mute;
-            m_engine.mute(2, v3mute);
+            m_engine.mute(0, 2, v3mute);
+        break;
+
+        case A_TOGGLE_VOICE4:
+            v4mute = !v4mute;
+            m_engine.mute(1, 0, v4mute);
+        break;
+
+        case A_TOGGLE_VOICE5:
+            v5mute = !v5mute;
+            m_engine.mute(1, 1, v5mute);
+        break;
+
+        case A_TOGGLE_VOICE6:
+            v6mute = !v6mute;
+            m_engine.mute(1, 2, v6mute);
         break;
 
         case A_TOGGLE_FILTER:
@@ -868,4 +810,4 @@ void ConsolePlayer::decodeKeys ()
         break;
         }
     } while (_kbhit ());
-}
+}
\ No newline at end of file
