@@ -14,49 +14,16 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/***************************************************************************
- *  $Log: player.h,v $
- *  Revision 1.10  2004/02/12 05:58:03  s_a_white
- *  Update argurements and help menu handling.
- *
- *  Revision 1.9  2004/01/31 17:07:45  s_a_white
- *  Support of specifing max sids writes forming sid2crc and experimental
- *  TSID2 library support.
- *
- *  Revision 1.8  2003/06/27 21:09:37  s_a_white
- *  Constified some of the interfaces.
- *
- *  Revision 1.7  2003/02/20 18:50:45  s_a_white
- *  sid2crc support.
- *
- *  Revision 1.6  2002/01/29 08:11:43  s_a_white
- *  TSID filename fix
- *
- *  Revision 1.5  2002/01/28 19:40:50  s_a_white
- *  Added TSID support.
- *
- *  Revision 1.4  2001/12/05 22:22:48  s_a_white
- *  Added playerFast flag.
- *
- *  Revision 1.3  2001/12/03 19:17:34  s_a_white
- *  Corrected spelling of BUILDER.
- *
- *  Revision 1.2  2001/12/01 20:16:23  s_a_white
- *  Player changed to ConsolePlayer.
- *
- *  Revision 1.1  2001/11/27 19:10:44  s_a_white
- *  Initial Release.
- *
- ***************************************************************************/
 
 #ifndef _player_h_
 #define _player_h_
 
 #include "config.h"
-
-#include <sidplayfp/sidplay2.h>
+#include <sidplayfp/SidTune.h>
+#include <sidplayfp/sidplayfp.h>
 #include <sidplayfp/event.h>
-#include <sidplayfp/SidTuneMod.h>
+#include <sidplayfp/SidConfig.h>
+#include <sidplayfp/SidTuneInfo.h>
 #ifdef MSVC_HEADER_LOCATIONS
 #include <SidDatabase.h>
 #else
@@ -110,7 +77,7 @@ enum
     ERR_FILE_OPEN
 };
 
-void displayError (const char *arg0, uint num);
+void displayError (const char *arg0, unsigned int num);
 
 
 // Grouped global variables
@@ -131,9 +98,9 @@ private:
 #endif
 
     const char* const  m_name;
-    sidplay2           m_engine;
-    sid2_config_t      m_engCfg;
-    SidTuneMod         m_tune;
+    sidplayfp          m_engine;
+    SidConfig          m_engCfg;
+    SidTune            m_tune;
     player_state_t     m_state;
     const char*        m_outfile;
     EventContext      *m_context;
@@ -146,16 +113,15 @@ private:
     uint_least8_t      m_quietLevel;
     uint_least8_t      m_verboseLevel;
 
-    uint_least32_t     m_crc;
     bool               m_cpudebug;
 
     bool    v1mute, v2mute, v3mute;
+    bool    v4mute, v5mute, v6mute;
 
     int     m_precision;
 
     struct m_filter_t
     {
-//         SidFilter      definition;
         // Filter parameter for reSID
         double         bias;
         // Filter parameters for reSIDfp
@@ -208,21 +174,26 @@ private:
 
     // Command line args
     bool parseTime        (const char *str, uint_least32_t &time);
+    bool parseAddress      (const char *str, uint_least16_t &address);
     void displayArgs      (const char *arg = NULL);
     void displayDebugArgs ();
 
     bool createOutput   (OUTPUTS driver, const SidTuneInfo *tuneInfo);
     bool createSidEmu   (SIDEMUS emu);
     void displayError   (const char *error);
-    void displayError   (uint num) { ::displayError (m_name, num); }
+    void displayError   (unsigned int num) { ::displayError (m_name, num); }
     void decodeKeys     (void);
     void event          (void);
     void emuflush       (void);
     void menu           (void);
 
+    const char* getModel (SidTuneInfo::model_t model);
+
+    uint8_t* loadRom    (const char* romPath, const int size, const char defaultRom[]);
+
 public:
     ConsolePlayer (const char * const name);
-    virtual ~ConsolePlayer() {;}
+    virtual ~ConsolePlayer() {}
 
     int            args  (int argc, const char *argv[]);
     bool           open  (void);
